==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/HTTPURLConnection__241.h <==
// final class gnu.java.net.protocol.http.HTTPURLConnection$1

// class file dependencies
// @dep_class fcf45edcf5ce635f gnu_java_net_protocol_http_HTTPURLConnection__241
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_HTTPURLConnection__241_H_
#define _JC_gnu_java_net_protocol_http_HTTPURLConnection__241_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Credentials$object;
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object;

typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$method$_init$f4016d9bbdcc6452(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object *, struct _jc_gnu_java_net_protocol_http_Credentials$object *);

// Virtual methods
extern struct _jc_gnu_java_net_protocol_http_Credentials$object *_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$method$getCredentials$36bd93b957c11d96(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$method_info$getCredentials$36bd93b957c11d96;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods {
	struct _jc_gnu_java_net_protocol_http_Credentials$object	*(*getCredentials$36bd93b957c11d96)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods	gnu_java_net_protocol_http_HTTPURLConnection__241;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs {
	struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object	*this;
	struct _jc_gnu_java_net_protocol_http_Credentials$object	*val__24creds;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs {
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs	gnu_java_net_protocol_http_HTTPURLConnection__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs	gnu_java_net_protocol_http_HTTPURLConnection__241;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object {
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_HTTPURLConnection__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_HTTPURLConnection__241_H_ */

==> jc-1.4.5.tar.gz: gnu/java/net/protocol/http/HTTPURLConnection__241.h <==
// final class gnu.java.net.protocol.http.HTTPURLConnection$1

// class file dependencies
// @dep_class c6bd6df6bcc32312 gnu_java_net_protocol_http_HTTPURLConnection__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_HTTPURLConnection__241_H_
#define _JC_gnu_java_net_protocol_http_HTTPURLConnection__241_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Credentials$object;
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object;

typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$method$_init$f4016d9bbdcc6452(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object *, struct _jc_gnu_java_net_protocol_http_Credentials$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_net_protocol_http_Credentials$object *_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$method$getCredentials$36bd93b957c11d96(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$method_info$getCredentials$36bd93b957c11d96;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods {
	struct _jc_gnu_java_net_protocol_http_Credentials$object	*(*getCredentials$36bd93b957c11d96)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vmethods	gnu_java_net_protocol_http_HTTPURLConnection__241;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs {
	struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object	*this;
	struct _jc_gnu_java_net_protocol_http_Credentials$object	*val__24creds;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs {
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_refs	gnu_java_net_protocol_http_HTTPURLConnection__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$sub_nonrefs	gnu_java_net_protocol_http_HTTPURLConnection__241;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$object {
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$vtype _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_HTTPURLConnection__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_HTTPURLConnection__241$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_HTTPURLConnection__241_H_ */
